@@ -19,8 +19,8 @@
 ;; URL:      https://github.com/meedstrom/org-mem
 ;; Created:  2025-03-15
 ;; Keywords: text
-;; Package-Version: 0.26.3
-;; Package-Revision: 0.26.3-0-ge4a0ed52f8e6
+;; Package-Version: 0.27.1
+;; Package-Revision: 0.27.1-0-g6d1d2129f595
 ;; Package-Requires: ((emacs "29.1") (el-job "2.7.1") (llama "0.5.0"))
 
 ;;; Commentary:
@@ -209,7 +209,7 @@ These are hooks called many times:
 
 This lets a function on these hooks sidestep the performance overhead of
 `with-temp-buffer' or `with-work-buffer', in favor of using the
-already current buffer:
+already current buffer.  Just erase it first:
     \(cl-assert (eq (current-buffer) org-mem-scratch))
     \(erase-buffer)
 
@@ -1272,28 +1272,9 @@ overrides a default message printed when `org-mem-do-cache-text' is t."
           (message nil)
           (redisplay))))))
 
-;; Transitional #33
-(defun org-mem--zip (list1 list2)
-  "Destructively zip two lists into one.
-Like the Dash expression \(-zip-with #\\='nconc list1 list2).
-
-LIST1 and LIST2 must be lists of identical length,
-and each element in them must be a list or nil."
-  (let (merged)
-    (while list1
-      (push (nconc (pop list1) (pop list2)) merged))
-    (when list2 (error "Lists differed in length"))
-    (nreverse merged)))
-
 (defvar org-mem--caused-retry nil)
 (defun org-mem--finalize-full-scan (parse-results)
   "Handle PARSE-RESULTS from `org-mem--scan-full'."
-  ;; Transitional #33
-  (let* ((ng-style-results parse-results)
-         (merged (pop ng-style-results)))
-    (while ng-style-results
-      (setq merged (org-mem--zip (pop ng-style-results) merged)))
-    (setq parse-results merged))
   (run-hook-with-args 'org-mem-pre-full-scan-functions parse-results)
   (mapc #'clrhash (hash-table-values org-mem--key<>subtable))
   (clrhash org-mem--title<>id)
@@ -1302,22 +1283,27 @@ and each element in them must be a list or nil."
   (clrhash org-mem--truename<>entries)
   (clrhash org-mem--internal-entry-id<>links)
   (setq org-mem--title-collisions nil)
-  (seq-let (bad-paths file-data entries links problems) parse-results
+  (let (bad-paths problems)
+
+    ;; Build tables.
+    (with-current-buffer (setq org-mem-scratch (get-buffer-create " *org-mem-scratch*" t))
+      (cl-loop for (bad-path problem file-data entries links) in parse-results do
+               (when bad-path (push bad-path bad-paths))
+               (when problem (push problem problems))
+               (puthash (car file-data) file-data org-mem--truename<>metadata)
+               (run-hook-with-args 'org-mem-record-file-functions file-data)
+               (dolist (entry entries)
+                 (org-mem--record-entry entry)
+                 (run-hook-with-args 'org-mem-record-entry-functions entry))
+               (dolist (link links)
+                 (push link (gethash (org-mem-link--internal-entry-id link)
+                                     org-mem--internal-entry-id<>links))
+                 (run-hook-with-args 'org-mem-record-link-functions link))))
     (org-mem--invalidate-file-names bad-paths)
-    (with-current-buffer
-        (setq org-mem-scratch (get-buffer-create " *org-mem-scratch*" t))
-      (dolist (fdata file-data)
-        (puthash (car fdata) fdata org-mem--truename<>metadata)
-        (run-hook-with-args 'org-mem-record-file-functions fdata))
-      (dolist (entry entries)
-        (org-mem--record-entry entry)
-        (run-hook-with-args 'org-mem-record-entry-functions entry))
-      (dolist (link links)
-        (push link (gethash (org-mem-link--internal-entry-id link)
-                            org-mem--internal-entry-id<>links))
-        (run-hook-with-args 'org-mem-record-link-functions link)))
     (org-mem--rebuild-specially-indexed-tables)
 
+    ;; Message on interactive reset.
+    ;; Ensure the message can be edited by `org-mem-post-full-scan-functions'.
     (setq org-mem--time-elapsed
           (float-time (time-since org-mem--time-at-begin-full-scan)))
     (when org-mem--next-message
@@ -1339,6 +1325,7 @@ and each element in them must be a list or nil."
           (message "%s" (concat org-mem--reset-msg " done"))
         (message nil)))
 
+    ;; Other stuff.
     (while org-mem-initial-scan-hook
       (funcall (pop org-mem-initial-scan-hook)))
     (when bad-paths
@@ -1751,6 +1738,30 @@ BUFNAME defaults to \" *org-mem-org-mode-scratch*\"."
       (message msg)
       msg)))
 
+(defun org-mem-translate-parse-results (ng-style-results)
+  "Translate NG-STYLE-RESULTS into style from before org-mem 0.27.0.
+
+This is a transition helper.  Org-mem 0.27.0 changed the style of
+PARSE-RESULTS passed to `org-mem-pre-full-scan-functions' & co.
+
+For reference, the new style is a list as long as the number of files,
+each element being a list:
+
+   \(BAD-PATH PROBLEM FILE-DATUM ENTRIES LINKS)
+
+Old style was a list of 5 lists:
+
+   \(BAD-PATHS FILE-DATA ENTRIES LINKS PROBLEMS)"
+  (cl-loop
+   for (badpath problem fdatum entries links) in (copy-sequence ng-style-results)
+   when badpath collect badpath into badpaths
+   when problem collect problem into problems
+   when fdatum collect fdatum into fdata
+   nconc entries into all-entries
+   nconc links into all-links
+   finally return (list badpaths fdata all-entries all-links problems)))
+
+
 
 ;;; End-user tool
 
@@ -1798,7 +1809,9 @@ org-id-locations:
       (org-mem--scan-full))))
 
 
-(defvar org-mem--bump-int 20 "Not a version number, but bumped sometimes.")
+(defvaralias 'org-mem-internal-version 'org-mem--bump-int) ; Alias added 2026-01-27 (after 0.26.3)
+(defconst org-mem--bump-int 23 "Not a version number, but bumped sometimes.")
+
 (defmacro org-mem--def-whiny-alias (old new when removed-by)
   "Define function OLD as effectively an alias for NEW.
 Also, calling OLD will emit a deprecation warning the first time.
